CryptoProvider

Trait CryptoProvider 

pub trait CryptoProvider:
    Send
    + Sync
    + 'static {
    // Required methods
    fn server_config(&self) -> Arc<ServerConfig>;
    fn fips_mode(&self) -> bool;
}
The pluggable TLS backend.

Hands out a ready ServerConfig for terminating downstream TLS and reports whether the backend is operating in a FIPS-validated mode (provider-dependent: false for the ring build, true for the aws-lc-rs FIPS build).

Required Methods

fn server_config(&self) -> Arc<ServerConfig>

The server-side TLS configuration for terminating client connections.

fn fips_mode(&self) -> bool

Whether the backend is a FIPS-validated module in FIPS mode.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl CryptoProvider for RingProvider

Available on crate feature non-fips only.