pub fn classify(method: HttpMethod, path: &str) -> ClassifiedExpand description
Classifies a method + path into an endpoint, logical index, and doc id.
The path’s query string, if any, must already be stripped by the caller.
pub fn classify(method: HttpMethod, path: &str) -> ClassifiedClassifies a method + path into an endpoint, logical index, and doc id.
The path’s query string, if any, must already be stripped by the caller.